/*
   Kafel - syscalls (AMD64)
   -----------------------------------------

   Copyright 2016 Google Inc. All Rights Reserved.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

#include "../syscall.h"

#include <stddef.h>

#define ARG_0 0
#define ARG_1 1
#define ARG_2 2
#define ARG_3 3
#define ARG_4 4
#define ARG_5 5

#define NORMAL false

const struct syscall_descriptor amd64_syscall_list[] = {
    {"accept",
     43,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"upeer_sockaddr", 8},
             [ARG_2] = {"upeer_addrlen", 8},
     }},
    {"accept4",
     288,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"upeer_sockaddr", 8},
             [ARG_2] = {"upeer_addrlen", 8}, [ARG_3] = {"flags", 4},
     }},
    {"access",
     21,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"mode", 4},
     }},
    {"acct",
     163,
     NORMAL,
     {
             [ARG_0] = {"name", 8},
     }},
    {"add_key",
     248,
     NORMAL,
     {
             [ARG_0] = {"_type", 8}, [ARG_1] = {"_description", 8},
             [ARG_2] = {"_payload", 8}, [ARG_3] = {"plen", 8},
             [ARG_4] = {"ringid", 4},
     }},
    {"adjtimex",
     159,
     NORMAL,
     {
             [ARG_0] = {"txc_p", 8},
     }},
    {"afs_syscall", 183, NORMAL, {}},  // Unimplemented system call
    {"alarm",
     37,
     NORMAL,
     {
             [ARG_0] = {"seconds", 4},
     }},
    {"arch_prctl",
     158,
     NORMAL,
     {
             [ARG_0] = {"code", 4}, [ARG_1] = {"addr", 8},
     }},
    {"bind",
     49,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"umyaddr", 8},
             [ARG_2] = {"addrlen", 4},
     }},
    {"bpf",
     321,
     NORMAL,
     {
             [ARG_0] = {"cmd", 4}, [ARG_1] = {"uattr", 8},
             [ARG_2] = {"size", 4},
     }},
    {"brk",
     12,
     NORMAL,
     {
             [ARG_0] = {"brk", 8},
     }},
    {"capget",
     125,
     NORMAL,
     {
             [ARG_0] = {"header", 8}, [ARG_1] = {"dataptr", 8},
     }},
    {"capset",
     126,
     NORMAL,
     {
             [ARG_0] = {"header", 8}, [ARG_1] = {"data", 8},
     }},
    {"chdir",
     80,
     NORMAL,
     {
             [ARG_0] = {"filename", 8},
     }},
    {"chmod",
     90,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"mode", 2},
     }},
    {"chown",
     92,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"user", 4},
             [ARG_2] = {"group", 4},
     }},
    {"chroot",
     161,
     NORMAL,
     {
             [ARG_0] = {"filename", 8},
     }},
    {"clock_adjtime",
     305,
     NORMAL,
     {
             [ARG_0] = {"which_clock", 4}, [ARG_1] = {"utx", 8},
     }},
    {"clock_getres",
     229,
     NORMAL,
     {
             [ARG_0] = {"which_clock", 4}, [ARG_1] = {"tp", 8},
     }},
    {"clock_gettime",
     228,
     NORMAL,
     {
             [ARG_0] = {"which_clock", 4}, [ARG_1] = {"tp", 8},
     }},
    {"clock_nanosleep",
     230,
     NORMAL,
     {
             [ARG_0] = {"which_clock", 4}, [ARG_1] = {"flags", 4},
             [ARG_2] = {"rqtp", 8}, [ARG_3] = {"rmtp", 8},
     }},
    {"clock_settime",
     227,
     NORMAL,
     {
             [ARG_0] = {"which_clock", 4}, [ARG_1] = {"tp", 8},
     }},
    {"clone",
     56,
     NORMAL,
     {
             [ARG_0] = {"clone_flags", 8}, [ARG_1] = {"newsp", 8},
             [ARG_2] = {"parent_tidptr", 8}, [ARG_3] = {"child_tidptr", 8},
             [ARG_4] = {"tls", 8},
     }},
    {"close",
     3,
     NORMAL,
     {
             [ARG_0] = {"fd", 4},
     }},
    {"connect",
     42,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"uservaddr", 8},
             [ARG_2] = {"addrlen", 4},
     }},
    {"copy_file_range",
     326,
     NORMAL,
     {
             [ARG_0] = {"fd_in", 4}, [ARG_1] = {"off_in", 8},
             [ARG_2] = {"fd_out", 4}, [ARG_3] = {"off_out", 8},
             [ARG_4] = {"len", 8}, [ARG_5] = {"flags", 4},
     }},
    {"creat",
     85,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"mode", 2},
     }},
    {"create_module",
     174,
     NORMAL,
     {
             [ARG_0] = {"name", 8}, [ARG_1] = {"size", 8},
     }},  // only in kernels before Linux 2.6
    {"delete_module",
     176,
     NORMAL,
     {
             [ARG_0] = {"name_user", 8}, [ARG_1] = {"flags", 4},
     }},
    {"dup",
     32,
     NORMAL,
     {
             [ARG_0] = {"fildes", 4},
     }},
    {"dup2",
     33,
     NORMAL,
     {
             [ARG_0] = {"oldfd", 4}, [ARG_1] = {"newfd", 4},
     }},
    {"dup3",
     292,
     NORMAL,
     {
             [ARG_0] = {"oldfd", 4}, [ARG_1] = {"newfd", 4},
             [ARG_2] = {"flags", 4},
     }},
    {"epoll_create",
     213,
     NORMAL,
     {
             [ARG_0] = {"size", 4},
     }},
    {"epoll_create1",
     291,
     NORMAL,
     {
             [ARG_0] = {"flags", 4},
     }},
    {"epoll_ctl",
     233,
     NORMAL,
     {
             [ARG_0] = {"epfd", 4}, [ARG_1] = {"op", 4}, [ARG_2] = {"fd", 4},
             [ARG_3] = {"event", 8},
     }},
    {"epoll_ctl_old", 214, NORMAL, {}},  // old/Unimplemented system call
    {"epoll_pwait",
     281,
     NORMAL,
     {
             [ARG_0] = {"epfd", 4}, [ARG_1] = {"events", 8},
             [ARG_2] = {"maxevents", 4}, [ARG_3] = {"timeout", 4},
             [ARG_4] = {"sigmask", 8}, [ARG_5] = {"sigsetsize", 8},
     }},
    {"epoll_wait",
     232,
     NORMAL,
     {
             [ARG_0] = {"epfd", 4}, [ARG_1] = {"events", 8},
             [ARG_2] = {"maxevents", 4}, [ARG_3] = {"timeout", 4},
     }},
    {"epoll_wait_old", 215, NORMAL, {}},  // old/Unimplemented system call
    {"eventfd",
     284,
     NORMAL,
     {
             [ARG_0] = {"count", 4},
     }},
    {"eventfd2",
     290,
     NORMAL,
     {
             [ARG_0] = {"count", 4}, [ARG_1] = {"flags", 4},
     }},
    {"execve",
     59,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"argv", 8},
             [ARG_2] = {"envp", 8},
     }},
    {"execveat",
     322,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"argv", 8}, [ARG_3] = {"envp", 8},
             [ARG_4] = {"flags", 4},
     }},
    {"exit",
     60,
     NORMAL,
     {
             [ARG_0] = {"error_code", 4},
     }},
    {"exit_group",
     231,
     NORMAL,
     {
             [ARG_0] = {"error_code", 4},
     }},
    {"faccessat",
     269,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"mode", 4},
     }},
    {"fadvise64",
     221,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"offset", 8}, [ARG_2] = {"len", 8},
             [ARG_3] = {"advice", 4},
     }},
    {"fallocate",
     285,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"mode", 4},
             [ARG_2] = {"offset", 8}, [ARG_3] = {"len", 8},
     }},
    {"fanotify_init",
     300,
     NORMAL,
     {
             [ARG_0] = {"flags", 4}, [ARG_1] = {"event_f_flags", 4},
     }},
    {"fanotify_mark",
     301,
     NORMAL,
     {
             [ARG_0] = {"fanotify_fd", 4}, [ARG_1] = {"flags", 4},
             [ARG_2] = {"mask", 8}, [ARG_3] = {"dfd", 4},
             [ARG_4] = {"pathname", 8},
     }},
    {"fchdir",
     81,
     NORMAL,
     {
             [ARG_0] = {"fd", 4},
     }},
    {"fchmod",
     91,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"mode", 2},
     }},
    {"fchmodat",
     268,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"mode", 2},
     }},
    {"fchown",
     93,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"user", 4}, [ARG_2] = {"group", 4},
     }},
    {"fchownat",
     260,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"user", 4}, [ARG_3] = {"group", 4},
             [ARG_4] = {"flag", 4},
     }},
    {"fcntl",
     72,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"cmd", 4}, [ARG_2] = {"arg", 8},
     }},
    {"fdatasync",
     75,
     NORMAL,
     {
             [ARG_0] = {"fd", 4},
     }},
    {"fgetxattr",
     193,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"name", 8}, [ARG_2] = {"value", 8},
             [ARG_3] = {"size", 8},
     }},
    {"finit_module",
     313,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"uargs", 8},
             [ARG_2] = {"flags", 4},
     }},
    {"flistxattr",
     196,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"list", 8}, [ARG_2] = {"size", 8},
     }},
    {"flock",
     73,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"cmd", 4},
     }},
    {"fork", 57, NORMAL, {}},
    {"fremovexattr",
     199,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"name", 8},
     }},
    {"fsetxattr",
     190,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"name", 8}, [ARG_2] = {"value", 8},
             [ARG_3] = {"size", 8}, [ARG_4] = {"flags", 4},
     }},
    {"fstatfs",
     138,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"buf", 8},
     }},
    {"fsync",
     74,
     NORMAL,
     {
             [ARG_0] = {"fd", 4},
     }},
    {"ftruncate",
     77,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"length", 8},
     }},
    {"futex",
     202,
     NORMAL,
     {
             [ARG_0] = {"uaddr", 8}, [ARG_1] = {"op", 4}, [ARG_2] = {"val", 4},
             [ARG_3] = {"utime", 8}, [ARG_4] = {"uaddr2", 8},
             [ARG_5] = {"val3", 4},
     }},
    {"futimesat",
     261,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"utimes", 8},
     }},
    {"getcpu",
     309,
     NORMAL,
     {
             [ARG_0] = {"cpup", 8}, [ARG_1] = {"nodep", 8},
             [ARG_2] = {"unused", 8},
     }},
    {"getcwd",
     79,
     NORMAL,
     {
             [ARG_0] = {"buf", 8}, [ARG_1] = {"size", 8},
     }},
    {"getdents",
     78,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"dirent", 8},
             [ARG_2] = {"count", 4},
     }},
    {"getdents64",
     217,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"dirent", 8},
             [ARG_2] = {"count", 4},
     }},
    {"getegid", 108, NORMAL, {}},
    {"geteuid", 107, NORMAL, {}},
    {"getgid", 104, NORMAL, {}},
    {"getgroups",
     115,
     NORMAL,
     {
             [ARG_0] = {"gidsetsize", 4}, [ARG_1] = {"grouplist", 8},
     }},
    {"getitimer",
     36,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"value", 8},
     }},
    {"get_kernel_syms",
     177,
     NORMAL,
     {
             [ARG_0] = {"table", 8},
     }},  // only in kernels before Linux 2.6
    {"get_mempolicy",
     239,
     NORMAL,
     {
             [ARG_0] = {"policy", 8}, [ARG_1] = {"nmask", 8},
             [ARG_2] = {"maxnode", 8}, [ARG_3] = {"addr", 8},
             [ARG_4] = {"flags", 8},
     }},
    {"getpeername",
     52,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"usockaddr", 8},
             [ARG_2] = {"usockaddr_len", 8},
     }},
    {"getpgid",
     121,
     NORMAL,
     {
             [ARG_0] = {"pid", 4},
     }},
    {"getpgrp", 111, NORMAL, {}},
    {"getpid", 39, NORMAL, {}},
    {"getpmsg", 181, NORMAL, {}},  // Unimplemented system call
    {"getppid", 110, NORMAL, {}},
    {"getpriority",
     140,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"who", 4},
     }},
    {"getrandom",
     318,
     NORMAL,
     {
             [ARG_0] = {"buf", 8}, [ARG_1] = {"count", 8},
             [ARG_2] = {"flags", 4},
     }},
    {"getresgid",
     120,
     NORMAL,
     {
             [ARG_0] = {"rgidp", 8}, [ARG_1] = {"egidp", 8},
             [ARG_2] = {"sgidp", 8},
     }},
    {"getresuid",
     118,
     NORMAL,
     {
             [ARG_0] = {"ruidp", 8}, [ARG_1] = {"euidp", 8},
             [ARG_2] = {"suidp", 8},
     }},
    {"getrlimit",
     97,
     NORMAL,
     {
             [ARG_0] = {"resource", 4}, [ARG_1] = {"rlim", 8},
     }},
    {"get_robust_list",
     274,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"head_ptr", 8},
             [ARG_2] = {"len_ptr", 8},
     }},
    {"getrusage",
     98,
     NORMAL,
     {
             [ARG_0] = {"who", 4}, [ARG_1] = {"ru", 8},
     }},
    {"getsid",
     124,
     NORMAL,
     {
             [ARG_0] = {"pid", 4},
     }},
    {"getsockname",
     51,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"usockaddr", 8},
             [ARG_2] = {"usockaddr_len", 8},
     }},
    {"getsockopt",
     55,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"level", 4},
             [ARG_2] = {"optname", 4}, [ARG_3] = {"optval", 8},
             [ARG_4] = {"optlen", 8},
     }},
    {"get_thread_area",
     211,
     NORMAL,
     {
             [ARG_0] = {"u_info", 8},
     }},
    {"gettid", 186, NORMAL, {}},
    {"gettimeofday",
     96,
     NORMAL,
     {
             [ARG_0] = {"tv", 8}, [ARG_1] = {"tz", 8},
     }},
    {"getuid", 102, NORMAL, {}},
    {"getxattr",
     191,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"name", 8},
             [ARG_2] = {"value", 8}, [ARG_3] = {"size", 8},
     }},
    {"init_module",
     175,
     NORMAL,
     {
             [ARG_0] = {"umod", 8}, [ARG_1] = {"len", 8},
             [ARG_2] = {"uargs", 8},
     }},
    {"inotify_add_watch",
     254,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"pathname", 8},
             [ARG_2] = {"mask", 4},
     }},
    {"inotify_init", 253, NORMAL, {}},
    {"inotify_init1",
     294,
     NORMAL,
     {
             [ARG_0] = {"flags", 4},
     }},
    {"inotify_rm_watch",
     255,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"wd", 4},
     }},
    {"io_cancel",
     210,
     NORMAL,
     {
             [ARG_0] = {"ctx_id", 8}, [ARG_1] = {"iocb", 8},
             [ARG_2] = {"result", 8},
     }},
    {"ioctl",
     16,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"cmd", 4}, [ARG_2] = {"arg", 8},
     }},
    {"io_destroy",
     207,
     NORMAL,
     {
             [ARG_0] = {"ctx", 8},
     }},
    {"io_getevents",
     208,
     NORMAL,
     {
             [ARG_0] = {"ctx_id", 8}, [ARG_1] = {"min_nr", 8},
             [ARG_2] = {"nr", 8}, [ARG_3] = {"events", 8},
             [ARG_4] = {"timeout", 8},
     }},
    {"ioperm",
     173,
     NORMAL,
     {
             [ARG_0] = {"from", 8}, [ARG_1] = {"num", 8},
             [ARG_2] = {"turn_on", 4},
     }},
    {"iopl",
     172,
     NORMAL,
     {
             [ARG_0] = {"level", 4},
     }},
    {"ioprio_get",
     252,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"who", 4},
     }},
    {"ioprio_set",
     251,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"who", 4},
             [ARG_2] = {"ioprio", 4},
     }},
    {"io_setup",
     206,
     NORMAL,
     {
             [ARG_0] = {"nr_events", 4}, [ARG_1] = {"ctxp", 8},
     }},
    {"io_submit",
     209,
     NORMAL,
     {
             [ARG_0] = {"ctx_id", 8}, [ARG_1] = {"nr", 8},
             [ARG_2] = {"iocbpp", 8},
     }},
    {"kcmp",
     312,
     NORMAL,
     {
             [ARG_0] = {"pid1", 4}, [ARG_1] = {"pid2", 4},
             [ARG_2] = {"type", 4}, [ARG_3] = {"idx1", 8},
             [ARG_4] = {"idx2", 8},
     }},
    {"kexec_file_load",
     320,
     NORMAL,
     {
             [ARG_0] = {"kernel_fd", 4}, [ARG_1] = {"initrd_fd", 4},
             [ARG_2] = {"cmdline_len", 8}, [ARG_3] = {"cmdline_ptr", 8},
             [ARG_4] = {"flags", 8},
     }},
    {"kexec_load",
     246,
     NORMAL,
     {
             [ARG_0] = {"entry", 8}, [ARG_1] = {"nr_segments", 8},
             [ARG_2] = {"segments", 8}, [ARG_3] = {"flags", 8},
     }},
    {"keyctl",
     250,
     NORMAL,
     {
             [ARG_0] = {"option", 4}, [ARG_1] = {"arg2", 8},
             [ARG_2] = {"arg3", 8}, [ARG_3] = {"arg4", 8},
             [ARG_4] = {"arg5", 8},
     }},
    {"kill",
     62,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"sig", 4},
     }},
    {"lchown",
     94,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"user", 4},
             [ARG_2] = {"group", 4},
     }},
    {"lgetxattr",
     192,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"name", 8},
             [ARG_2] = {"value", 8}, [ARG_3] = {"size", 8},
     }},
    {"link",
     86,
     NORMAL,
     {
             [ARG_0] = {"oldname", 8}, [ARG_1] = {"newname", 8},
     }},
    {"linkat",
     265,
     NORMAL,
     {
             [ARG_0] = {"olddfd", 4}, [ARG_1] = {"oldname", 8},
             [ARG_2] = {"newdfd", 4}, [ARG_3] = {"newname", 8},
             [ARG_4] = {"flags", 4},
     }},
    {"listen",
     50,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"backlog", 4},
     }},
    {"listxattr",
     194,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"list", 8},
             [ARG_2] = {"size", 8},
     }},
    {"llistxattr",
     195,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"list", 8},
             [ARG_2] = {"size", 8},
     }},
    {"lookup_dcookie",
     212,
     NORMAL,
     {
             [ARG_0] = {"cookie64", 8}, [ARG_1] = {"buf", 8},
             [ARG_2] = {"len", 8},
     }},
    {"lremovexattr",
     198,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"name", 8},
     }},
    {"lseek",
     8,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"offset", 8},
             [ARG_2] = {"whence", 4},
     }},
    {"lsetxattr",
     189,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"name", 8},
             [ARG_2] = {"value", 8}, [ARG_3] = {"size", 8},
             [ARG_4] = {"flags", 4},
     }},
    {"madvise",
     28,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len_in", 8},
             [ARG_2] = {"behavior", 4},
     }},
    {"mbind",
     237,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8},
             [ARG_2] = {"mode", 8}, [ARG_3] = {"nmask", 8},
             [ARG_4] = {"maxnode", 8}, [ARG_5] = {"flags", 4},
     }},
    {"membarrier",
     324,
     NORMAL,
     {
             [ARG_0] = {"cmd", 4}, [ARG_1] = {"flags", 4},
     }},
    {"memfd_create",
     319,
     NORMAL,
     {
             [ARG_0] = {"uname", 8}, [ARG_1] = {"flags", 4},
     }},
    {"migrate_pages",
     256,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"maxnode", 8},
             [ARG_2] = {"old_nodes", 8}, [ARG_3] = {"new_nodes", 8},
     }},
    {"mincore",
     27,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8}, [ARG_2] = {"vec", 8},
     }},
    {"mkdir",
     83,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"mode", 2},
     }},
    {"mkdirat",
     258,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"pathname", 8},
             [ARG_2] = {"mode", 2},
     }},
    {"mknod",
     133,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"mode", 2},
             [ARG_2] = {"dev", 4},
     }},
    {"mknodat",
     259,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"mode", 2}, [ARG_3] = {"dev", 4},
     }},
    {"mlock",
     149,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8},
     }},
    {"mlock2",
     325,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8},
             [ARG_2] = {"flags", 4},
     }},
    {"mlockall",
     151,
     NORMAL,
     {
             [ARG_0] = {"flags", 4},
     }},
    {"mmap",
     9,
     NORMAL,
     {
             [ARG_0] = {"addr", 8}, [ARG_1] = {"len", 8}, [ARG_2] = {"prot", 8},
             [ARG_3] = {"flags", 8}, [ARG_4] = {"fd", 8}, [ARG_5] = {"off", 8},
     }},
    {"modify_ldt",
     154,
     NORMAL,
     {
             [ARG_0] = {"func", 4}, [ARG_1] = {"ptr", 8},
             [ARG_2] = {"bytecount", 8},
     }},
    {"mount",
     165,
     NORMAL,
     {
             [ARG_0] = {"dev_name", 8}, [ARG_1] = {"dir_name", 8},
             [ARG_2] = {"type", 8}, [ARG_3] = {"flags", 8},
             [ARG_4] = {"data", 8},
     }},
    {"move_pages",
     279,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"nr_pages", 8},
             [ARG_2] = {"pages", 8}, [ARG_3] = {"nodes", 8},
             [ARG_4] = {"status", 8}, [ARG_5] = {"flags", 4},
     }},
    {"mprotect",
     10,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8},
             [ARG_2] = {"prot", 8},
     }},
    {"mq_getsetattr",
     245,
     NORMAL,
     {
             [ARG_0] = {"mqdes", 4}, [ARG_1] = {"u_mqstat", 8},
             [ARG_2] = {"u_omqstat", 8},
     }},
    {"mq_notify",
     244,
     NORMAL,
     {
             [ARG_0] = {"mqdes", 4}, [ARG_1] = {"u_notification", 8},
     }},
    {"mq_open",
     240,
     NORMAL,
     {
             [ARG_0] = {"u_name", 8}, [ARG_1] = {"oflag", 4},
             [ARG_2] = {"mode", 2}, [ARG_3] = {"u_attr", 8},
     }},
    {"mq_timedreceive",
     243,
     NORMAL,
     {
             [ARG_0] = {"mqdes", 4}, [ARG_1] = {"u_msg_ptr", 8},
             [ARG_2] = {"msg_len", 8}, [ARG_3] = {"u_msg_prio", 8},
             [ARG_4] = {"u_abs_timeout", 8},
     }},
    {"mq_timedsend",
     242,
     NORMAL,
     {
             [ARG_0] = {"mqdes", 4}, [ARG_1] = {"u_msg_ptr", 8},
             [ARG_2] = {"msg_len", 8}, [ARG_3] = {"msg_prio", 4},
             [ARG_4] = {"u_abs_timeout", 8},
     }},
    {"mq_unlink",
     241,
     NORMAL,
     {
             [ARG_0] = {"u_name", 8},
     }},
    {"mremap",
     25,
     NORMAL,
     {
             [ARG_0] = {"addr", 8}, [ARG_1] = {"old_len", 8},
             [ARG_2] = {"new_len", 8}, [ARG_3] = {"flags", 8},
             [ARG_4] = {"new_addr", 8},
     }},
    {"msgctl",
     71,
     NORMAL,
     {
             [ARG_0] = {"msqid", 4}, [ARG_1] = {"cmd", 4}, [ARG_2] = {"buf", 8},
     }},
    {"msgget",
     68,
     NORMAL,
     {
             [ARG_0] = {"key", 4}, [ARG_1] = {"msgflg", 4},
     }},
    {"msgrcv",
     70,
     NORMAL,
     {
             [ARG_0] = {"msqid", 4}, [ARG_1] = {"msgp", 8},
             [ARG_2] = {"msgsz", 8}, [ARG_3] = {"msgtyp", 8},
             [ARG_4] = {"msgflg", 4},
     }},
    {"msgsnd",
     69,
     NORMAL,
     {
             [ARG_0] = {"msqid", 4}, [ARG_1] = {"msgp", 8},
             [ARG_2] = {"msgsz", 8}, [ARG_3] = {"msgflg", 4},
     }},
    {"msync",
     26,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8},
             [ARG_2] = {"flags", 4},
     }},
    {"munlock",
     150,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"len", 8},
     }},
    {"munlockall", 152, NORMAL, {}},
    {"munmap",
     11,
     NORMAL,
     {
             [ARG_0] = {"addr", 8}, [ARG_1] = {"len", 8},
     }},
    {"name_to_handle_at",
     303,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"name", 8},
             [ARG_2] = {"handle", 8}, [ARG_3] = {"mnt_id", 8},
             [ARG_4] = {"flag", 4},
     }},
    {"nanosleep",
     35,
     NORMAL,
     {
             [ARG_0] = {"rqtp", 8}, [ARG_1] = {"rmtp", 8},
     }},
    {"newfstat",
     5,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"statbuf", 8},
     }},
    {"newfstatat",
     262,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"statbuf", 8}, [ARG_3] = {"flag", 4},
     }},
    {"newlstat",
     6,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"statbuf", 8},
     }},
    {"newstat",
     4,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"statbuf", 8},
     }},
    {"newuname",
     63,
     NORMAL,
     {
             [ARG_0] = {"name", 8},
     }},
    {"nfsservctl",
     180,
     NORMAL,
     {
             [ARG_0] = {"cmd", 4}, [ARG_1] = {"argp", 8}, [ARG_2] = {"resp", 8},
     }},  // only in kernels before Linux 3.1
    {"open",
     2,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"flags", 4},
             [ARG_2] = {"mode", 2},
     }},
    {"openat",
     257,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"flags", 4}, [ARG_3] = {"mode", 2},
     }},
    {"open_by_handle_at",
     304,
     NORMAL,
     {
             [ARG_0] = {"mountdirfd", 4}, [ARG_1] = {"handle", 8},
             [ARG_2] = {"flags", 4},
     }},
    {"pause", 34, NORMAL, {}},
    {"perf_event_open",
     298,
     NORMAL,
     {
             [ARG_0] = {"attr_uptr", 8}, [ARG_1] = {"pid", 4},
             [ARG_2] = {"cpu", 4}, [ARG_3] = {"group_fd", 4},
             [ARG_4] = {"flags", 8},
     }},
    {"personality",
     135,
     NORMAL,
     {
             [ARG_0] = {"personality", 4},
     }},
    {"pipe",
     22,
     NORMAL,
     {
             [ARG_0] = {"fildes", 8},
     }},
    {"pipe2",
     293,
     NORMAL,
     {
             [ARG_0] = {"fildes", 8}, [ARG_1] = {"flags", 4},
     }},
    {"pivot_root",
     155,
     NORMAL,
     {
             [ARG_0] = {"new_root", 8}, [ARG_1] = {"put_old", 8},
     }},
    {"poll",
     7,
     NORMAL,
     {
             [ARG_0] = {"ufds", 8}, [ARG_1] = {"nfds", 4},
             [ARG_2] = {"timeout_msecs", 4},
     }},
    {"ppoll",
     271,
     NORMAL,
     {
             [ARG_0] = {"ufds", 8}, [ARG_1] = {"nfds", 4}, [ARG_2] = {"tsp", 8},
             [ARG_3] = {"sigmask", 8}, [ARG_4] = {"sigsetsize", 8},
     }},
    {"prctl",
     157,
     NORMAL,
     {
             [ARG_0] = {"option", 4}, [ARG_1] = {"arg2", 8},
             [ARG_2] = {"arg3", 8}, [ARG_3] = {"arg4", 8},
             [ARG_4] = {"arg5", 8},
     }},
    {"pread64",
     17,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"buf", 8}, [ARG_2] = {"count", 8},
             [ARG_3] = {"pos", 8},
     }},
    {"preadv",
     295,
     NORMAL,
     {
             [ARG_0] = {"fd", 8}, [ARG_1] = {"vec", 8}, [ARG_2] = {"vlen", 8},
             [ARG_3] = {"pos_l", 8}, [ARG_4] = {"pos_h", 8},
     }},
    {"preadv2",
     327,
     NORMAL,
     {
             [ARG_0] = {"fd", 8}, [ARG_1] = {"vec", 8}, [ARG_2] = {"vlen", 8},
             [ARG_3] = {"pos_l", 8}, [ARG_4] = {"pos_h", 8},
             [ARG_5] = {"flags", 4},
     }},
    {"prlimit64",
     302,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"resource", 4},
             [ARG_2] = {"new_rlim", 8}, [ARG_3] = {"old_rlim", 8},
     }},
    {"process_vm_readv",
     310,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"lvec", 8},
             [ARG_2] = {"liovcnt", 8}, [ARG_3] = {"rvec", 8},
             [ARG_4] = {"riovcnt", 8}, [ARG_5] = {"flags", 8},
     }},
    {"process_vm_writev",
     311,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"lvec", 8},
             [ARG_2] = {"liovcnt", 8}, [ARG_3] = {"rvec", 8},
             [ARG_4] = {"riovcnt", 8}, [ARG_5] = {"flags", 8},
     }},
    {"pselect6",
     270,
     NORMAL,
     {
             [ARG_0] = {"n", 4}, [ARG_1] = {"inp", 8}, [ARG_2] = {"outp", 8},
             [ARG_3] = {"exp", 8}, [ARG_4] = {"tsp", 8}, [ARG_5] = {"sig", 8},
     }},
    {"ptrace",
     101,
     NORMAL,
     {
             [ARG_0] = {"request", 8}, [ARG_1] = {"pid", 8},
             [ARG_2] = {"addr", 8}, [ARG_3] = {"data", 8},
     }},
    {"putpmsg", 182, NORMAL, {}},  // Unimplemented system call
    {"pwrite64",
     18,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"buf", 8}, [ARG_2] = {"count", 8},
             [ARG_3] = {"pos", 8},
     }},
    {"pwritev",
     296,
     NORMAL,
     {
             [ARG_0] = {"fd", 8}, [ARG_1] = {"vec", 8}, [ARG_2] = {"vlen", 8},
             [ARG_3] = {"pos_l", 8}, [ARG_4] = {"pos_h", 8},
     }},
    {"pwritev2",
     328,
     NORMAL,
     {
             [ARG_0] = {"fd", 8}, [ARG_1] = {"vec", 8}, [ARG_2] = {"vlen", 8},
             [ARG_3] = {"pos_l", 8}, [ARG_4] = {"pos_h", 8},
             [ARG_5] = {"flags", 4},
     }},
    {"query_module",
     178,
     NORMAL,
     {
             [ARG_0] = {"name", 8}, [ARG_1] = {"which", 4},
             [ARG_2] = {"buf", 8}, [ARG_3] = {"bufsize", 8},
             [ARG_4] = {"ret", 8},
     }},  // only in kernels before Linux 2.6
    {"quotactl",
     179,
     NORMAL,
     {
             [ARG_0] = {"cmd", 4}, [ARG_1] = {"special", 8},
             [ARG_2] = {"id", 4}, [ARG_3] = {"addr", 8},
     }},
    {"read",
     0,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"buf", 8}, [ARG_2] = {"count", 8},
     }},
    {"readahead",
     187,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"offset", 8},
             [ARG_2] = {"count", 8},
     }},
    {"readlink",
     89,
     NORMAL,
     {
             [ARG_0] = {"path", 8}, [ARG_1] = {"buf", 8},
             [ARG_2] = {"bufsiz", 4},
     }},
    {"readlinkat",
     267,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"pathname", 8},
             [ARG_2] = {"buf", 8}, [ARG_3] = {"bufsiz", 4},
     }},
    {"readv",
     19,
     NORMAL,
     {
             [ARG_0] = {"fd", 8}, [ARG_1] = {"vec", 8}, [ARG_2] = {"vlen", 8},
     }},
    {"reboot",
     169,
     NORMAL,
     {
             [ARG_0] = {"magic1", 4}, [ARG_1] = {"magic2", 4},
             [ARG_2] = {"cmd", 4}, [ARG_3] = {"arg", 8},
     }},
    {"recvfrom",
     45,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"ubuf", 8}, [ARG_2] = {"size", 8},
             [ARG_3] = {"flags", 4}, [ARG_4] = {"addr", 8},
             [ARG_5] = {"addr_len", 8},
     }},
    {"recvmmsg",
     299,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"mmsg", 8}, [ARG_2] = {"vlen", 4},
             [ARG_3] = {"flags", 4}, [ARG_4] = {"timeout", 8},
     }},
    {"recvmsg",
     47,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"msg", 8}, [ARG_2] = {"flags", 4},
     }},
    {"remap_file_pages",
     216,
     NORMAL,
     {
             [ARG_0] = {"start", 8}, [ARG_1] = {"size", 8},
             [ARG_2] = {"prot", 8}, [ARG_3] = {"pgoff", 8},
             [ARG_4] = {"flags", 8},
     }},
    {"removexattr",
     197,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"name", 8},
     }},
    {"rename",
     82,
     NORMAL,
     {
             [ARG_0] = {"oldname", 8}, [ARG_1] = {"newname", 8},
     }},
    {"renameat",
     264,
     NORMAL,
     {
             [ARG_0] = {"olddfd", 4}, [ARG_1] = {"oldname", 8},
             [ARG_2] = {"newdfd", 4}, [ARG_3] = {"newname", 8},
     }},
    {"renameat2",
     316,
     NORMAL,
     {
             [ARG_0] = {"olddfd", 4}, [ARG_1] = {"oldname", 8},
             [ARG_2] = {"newdfd", 4}, [ARG_3] = {"newname", 8},
             [ARG_4] = {"flags", 4},
     }},
    {"request_key",
     249,
     NORMAL,
     {
             [ARG_0] = {"_type", 8}, [ARG_1] = {"_description", 8},
             [ARG_2] = {"_callout_info", 8}, [ARG_3] = {"destringid", 4},
     }},
    {"restart_syscall", 219, NORMAL, {}},
    {"rmdir",
     84,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8},
     }},
    {"rt_sigaction",
     13,
     NORMAL,
     {
             [ARG_0] = {"sig", 4}, [ARG_1] = {"act", 8}, [ARG_2] = {"oact", 8},
             [ARG_3] = {"sigsetsize", 8},
     }},
    {"rt_sigpending",
     127,
     NORMAL,
     {
             [ARG_0] = {"uset", 8}, [ARG_1] = {"sigsetsize", 8},
     }},
    {"rt_sigprocmask",
     14,
     NORMAL,
     {
             [ARG_0] = {"how", 4}, [ARG_1] = {"nset", 8}, [ARG_2] = {"oset", 8},
             [ARG_3] = {"sigsetsize", 8},
     }},
    {"rt_sigqueueinfo",
     129,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"sig", 4}, [ARG_2] = {"uinfo", 8},
     }},
    {"rt_sigreturn", 15, NORMAL, {}},
    {"rt_sigsuspend",
     130,
     NORMAL,
     {
             [ARG_0] = {"unewset", 8}, [ARG_1] = {"sigsetsize", 8},
     }},
    {"rt_sigtimedwait",
     128,
     NORMAL,
     {
             [ARG_0] = {"uthese", 8}, [ARG_1] = {"uinfo", 8},
             [ARG_2] = {"uts", 8}, [ARG_3] = {"sigsetsize", 8},
     }},
    {"rt_tgsigqueueinfo",
     297,
     NORMAL,
     {
             [ARG_0] = {"tgid", 4}, [ARG_1] = {"pid", 4}, [ARG_2] = {"sig", 4},
             [ARG_3] = {"uinfo", 8},
     }},
    {"sched_getaffinity",
     204,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"len", 4},
             [ARG_2] = {"user_mask_ptr", 8},
     }},
    {"sched_getattr",
     315,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"uattr", 8},
             [ARG_2] = {"size", 4}, [ARG_3] = {"flags", 4},
     }},
    {"sched_getparam",
     143,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"param", 8},
     }},
    {"sched_get_priority_max",
     146,
     NORMAL,
     {
             [ARG_0] = {"policy", 4},
     }},
    {"sched_get_priority_min",
     147,
     NORMAL,
     {
             [ARG_0] = {"policy", 4},
     }},
    {"sched_getscheduler",
     145,
     NORMAL,
     {
             [ARG_0] = {"pid", 4},
     }},
    {"sched_rr_get_interval",
     148,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"interval", 8},
     }},
    {"sched_setaffinity",
     203,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"len", 4},
             [ARG_2] = {"user_mask_ptr", 8},
     }},
    {"sched_setattr",
     314,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"uattr", 8},
             [ARG_2] = {"flags", 4},
     }},
    {"sched_setparam",
     142,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"param", 8},
     }},
    {"sched_setscheduler",
     144,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"policy", 4},
             [ARG_2] = {"param", 8},
     }},
    {"sched_yield", 24, NORMAL, {}},
    {"seccomp",
     317,
     NORMAL,
     {
             [ARG_0] = {"op", 4}, [ARG_1] = {"flags", 4},
             [ARG_2] = {"uargs", 8},
     }},
    {"security", 185, NORMAL, {}},  // Unimplemented system call
    {"select",
     23,
     NORMAL,
     {
             [ARG_0] = {"n", 4}, [ARG_1] = {"inp", 8}, [ARG_2] = {"outp", 8},
             [ARG_3] = {"exp", 8}, [ARG_4] = {"tvp", 8},
     }},
    {"semctl",
     66,
     NORMAL,
     {
             [ARG_0] = {"semid", 4}, [ARG_1] = {"semnum", 4},
             [ARG_2] = {"cmd", 4}, [ARG_3] = {"arg", 8},
     }},
    {"semget",
     64,
     NORMAL,
     {
             [ARG_0] = {"key", 4}, [ARG_1] = {"nsems", 4},
             [ARG_2] = {"semflg", 4},
     }},
    {"semop",
     65,
     NORMAL,
     {
             [ARG_0] = {"semid", 4}, [ARG_1] = {"tsops", 8},
             [ARG_2] = {"nsops", 4},
     }},
    {"semtimedop",
     220,
     NORMAL,
     {
             [ARG_0] = {"semid", 4}, [ARG_1] = {"tsops", 8},
             [ARG_2] = {"nsops", 4}, [ARG_3] = {"timeout", 8},
     }},
    {"sendfile64",
     40,
     NORMAL,
     {
             [ARG_0] = {"out_fd", 4}, [ARG_1] = {"in_fd", 4},
             [ARG_2] = {"offset", 8}, [ARG_3] = {"count", 8},
     }},
    {"sendmmsg",
     307,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"mmsg", 8}, [ARG_2] = {"vlen", 4},
             [ARG_3] = {"flags", 4},
     }},
    {"sendmsg",
     46,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"msg", 8}, [ARG_2] = {"flags", 4},
     }},
    {"sendto",
     44,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"buff", 8}, [ARG_2] = {"len", 8},
             [ARG_3] = {"flags", 4}, [ARG_4] = {"addr", 8},
             [ARG_5] = {"addr_len", 4},
     }},
    {"setdomainname",
     171,
     NORMAL,
     {
             [ARG_0] = {"name", 8}, [ARG_1] = {"len", 4},
     }},
    {"setfsgid",
     123,
     NORMAL,
     {
             [ARG_0] = {"gid", 4},
     }},
    {"setfsuid",
     122,
     NORMAL,
     {
             [ARG_0] = {"uid", 4},
     }},
    {"setgid",
     106,
     NORMAL,
     {
             [ARG_0] = {"gid", 4},
     }},
    {"setgroups",
     116,
     NORMAL,
     {
             [ARG_0] = {"gidsetsize", 4}, [ARG_1] = {"grouplist", 8},
     }},
    {"sethostname",
     170,
     NORMAL,
     {
             [ARG_0] = {"name", 8}, [ARG_1] = {"len", 4},
     }},
    {"setitimer",
     38,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"value", 8},
             [ARG_2] = {"ovalue", 8},
     }},
    {"set_mempolicy",
     238,
     NORMAL,
     {
             [ARG_0] = {"mode", 4}, [ARG_1] = {"nmask", 8},
             [ARG_2] = {"maxnode", 8},
     }},
    {"setns",
     308,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"nstype", 4},
     }},
    {"setpgid",
     109,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"pgid", 4},
     }},
    {"setpriority",
     141,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"who", 4},
             [ARG_2] = {"niceval", 4},
     }},
    {"setregid",
     114,
     NORMAL,
     {
             [ARG_0] = {"rgid", 4}, [ARG_1] = {"egid", 4},
     }},
    {"setresgid",
     119,
     NORMAL,
     {
             [ARG_0] = {"rgid", 4}, [ARG_1] = {"egid", 4},
             [ARG_2] = {"sgid", 4},
     }},
    {"setresuid",
     117,
     NORMAL,
     {
             [ARG_0] = {"ruid", 4}, [ARG_1] = {"euid", 4},
             [ARG_2] = {"suid", 4},
     }},
    {"setreuid",
     113,
     NORMAL,
     {
             [ARG_0] = {"ruid", 4}, [ARG_1] = {"euid", 4},
     }},
    {"setrlimit",
     160,
     NORMAL,
     {
             [ARG_0] = {"resource", 4}, [ARG_1] = {"rlim", 8},
     }},
    {"set_robust_list",
     273,
     NORMAL,
     {
             [ARG_0] = {"head", 8}, [ARG_1] = {"len", 8},
     }},
    {"setsid", 112, NORMAL, {}},
    {"setsockopt",
     54,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"level", 4},
             [ARG_2] = {"optname", 4}, [ARG_3] = {"optval", 8},
             [ARG_4] = {"optlen", 4},
     }},
    {"set_thread_area",
     205,
     NORMAL,
     {
             [ARG_0] = {"u_info", 8},
     }},
    {"set_tid_address",
     218,
     NORMAL,
     {
             [ARG_0] = {"tidptr", 8},
     }},
    {"settimeofday",
     164,
     NORMAL,
     {
             [ARG_0] = {"tv", 8}, [ARG_1] = {"tz", 8},
     }},
    {"setuid",
     105,
     NORMAL,
     {
             [ARG_0] = {"uid", 4},
     }},
    {"setxattr",
     188,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"name", 8},
             [ARG_2] = {"value", 8}, [ARG_3] = {"size", 8},
             [ARG_4] = {"flags", 4},
     }},
    {"shmat",
     30,
     NORMAL,
     {
             [ARG_0] = {"shmid", 4}, [ARG_1] = {"shmaddr", 8},
             [ARG_2] = {"shmflg", 4},
     }},
    {"shmctl",
     31,
     NORMAL,
     {
             [ARG_0] = {"shmid", 4}, [ARG_1] = {"cmd", 4}, [ARG_2] = {"buf", 8},
     }},
    {"shmdt",
     67,
     NORMAL,
     {
             [ARG_0] = {"shmaddr", 8},
     }},
    {"shmget",
     29,
     NORMAL,
     {
             [ARG_0] = {"key", 4}, [ARG_1] = {"size", 8},
             [ARG_2] = {"shmflg", 4},
     }},
    {"shutdown",
     48,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"how", 4},
     }},
    {"sigaltstack",
     131,
     NORMAL,
     {
             [ARG_0] = {"uss", 8}, [ARG_1] = {"uoss", 8},
     }},
    {"signalfd",
     282,
     NORMAL,
     {
             [ARG_0] = {"ufd", 4}, [ARG_1] = {"user_mask", 8},
             [ARG_2] = {"sizemask", 8},
     }},
    {"signalfd4",
     289,
     NORMAL,
     {
             [ARG_0] = {"ufd", 4}, [ARG_1] = {"user_mask", 8},
             [ARG_2] = {"sizemask", 8}, [ARG_3] = {"flags", 4},
     }},
    {"socket",
     41,
     NORMAL,
     {
             [ARG_0] = {"family", 4}, [ARG_1] = {"type", 4},
             [ARG_2] = {"protocol", 4},
     }},
    {"socketpair",
     53,
     NORMAL,
     {
             [ARG_0] = {"family", 4}, [ARG_1] = {"type", 4},
             [ARG_2] = {"protocol", 4}, [ARG_3] = {"usockvec", 8},
     }},
    {"splice",
     275,
     NORMAL,
     {
             [ARG_0] = {"fd_in", 4}, [ARG_1] = {"off_in", 8},
             [ARG_2] = {"fd_out", 4}, [ARG_3] = {"off_out", 8},
             [ARG_4] = {"len", 8}, [ARG_5] = {"flags", 4},
     }},
    {"statfs",
     137,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8}, [ARG_1] = {"buf", 8},
     }},
    {"swapoff",
     168,
     NORMAL,
     {
             [ARG_0] = {"specialfile", 8},
     }},
    {"swapon",
     167,
     NORMAL,
     {
             [ARG_0] = {"specialfile", 8}, [ARG_1] = {"swap_flags", 4},
     }},
    {"symlink",
     88,
     NORMAL,
     {
             [ARG_0] = {"oldname", 8}, [ARG_1] = {"newname", 8},
     }},
    {"symlinkat",
     266,
     NORMAL,
     {
             [ARG_0] = {"oldname", 8}, [ARG_1] = {"newdfd", 4},
             [ARG_2] = {"newname", 8},
     }},
    {"sync", 162, NORMAL, {}},
    {"sync_file_range",
     277,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"offset", 8},
             [ARG_2] = {"nbytes", 8}, [ARG_3] = {"flags", 4},
     }},
    {"syncfs",
     306,
     NORMAL,
     {
             [ARG_0] = {"fd", 4},
     }},
    {"sysctl",
     156,
     NORMAL,
     {
             [ARG_0] = {"args", 8},
     }},
    {"sysfs",
     139,
     NORMAL,
     {
             [ARG_0] = {"option", 4}, [ARG_1] = {"arg1", 8},
             [ARG_2] = {"arg2", 8},
     }},
    {"sysinfo",
     99,
     NORMAL,
     {
             [ARG_0] = {"info", 8},
     }},
    {"syslog",
     103,
     NORMAL,
     {
             [ARG_0] = {"type", 4}, [ARG_1] = {"buf", 8}, [ARG_2] = {"len", 4},
     }},
    {"tee",
     276,
     NORMAL,
     {
             [ARG_0] = {"fdin", 4}, [ARG_1] = {"fdout", 4},
             [ARG_2] = {"len", 8}, [ARG_3] = {"flags", 4},
     }},
    {"tgkill",
     234,
     NORMAL,
     {
             [ARG_0] = {"tgid", 4}, [ARG_1] = {"pid", 4}, [ARG_2] = {"sig", 4},
     }},
    {"time",
     201,
     NORMAL,
     {
             [ARG_0] = {"tloc", 8},
     }},
    {"timer_create",
     222,
     NORMAL,
     {
             [ARG_0] = {"which_clock", 4}, [ARG_1] = {"timer_event_spec", 8},
             [ARG_2] = {"created_timer_id", 8},
     }},
    {"timer_delete",
     226,
     NORMAL,
     {
             [ARG_0] = {"timer_id", 4},
     }},
    {"timerfd_create",
     283,
     NORMAL,
     {
             [ARG_0] = {"clockid", 4}, [ARG_1] = {"flags", 4},
     }},
    {"timerfd_gettime",
     287,
     NORMAL,
     {
             [ARG_0] = {"ufd", 4}, [ARG_1] = {"otmr", 8},
     }},
    {"timerfd_settime",
     286,
     NORMAL,
     {
             [ARG_0] = {"ufd", 4}, [ARG_1] = {"flags", 4},
             [ARG_2] = {"utmr", 8}, [ARG_3] = {"otmr", 8},
     }},
    {"timer_getoverrun",
     225,
     NORMAL,
     {
             [ARG_0] = {"timer_id", 4},
     }},
    {"timer_gettime",
     224,
     NORMAL,
     {
             [ARG_0] = {"timer_id", 4}, [ARG_1] = {"setting", 8},
     }},
    {"timer_settime",
     223,
     NORMAL,
     {
             [ARG_0] = {"timer_id", 4}, [ARG_1] = {"flags", 4},
             [ARG_2] = {"new_setting", 8}, [ARG_3] = {"old_setting", 8},
     }},
    {"times",
     100,
     NORMAL,
     {
             [ARG_0] = {"tbuf", 8},
     }},
    {"tkill",
     200,
     NORMAL,
     {
             [ARG_0] = {"pid", 4}, [ARG_1] = {"sig", 4},
     }},
    {"truncate",
     76,
     NORMAL,
     {
             [ARG_0] = {"path", 8}, [ARG_1] = {"length", 8},
     }},
    {"tuxcall", 184, NORMAL, {}},  // Unimplemented system call
    {"umask",
     95,
     NORMAL,
     {
             [ARG_0] = {"mask", 4},
     }},
    {"umount",
     166,
     NORMAL,
     {
             [ARG_0] = {"name", 8}, [ARG_1] = {"flags", 4},
     }},
    {"unlink",
     87,
     NORMAL,
     {
             [ARG_0] = {"pathname", 8},
     }},
    {"unlinkat",
     263,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"pathname", 8},
             [ARG_2] = {"flag", 4},
     }},
    {"unshare",
     272,
     NORMAL,
     {
             [ARG_0] = {"unshare_flags", 8},
     }},
    {"uselib",
     134,
     NORMAL,
     {
             [ARG_0] = {"library", 8},
     }},
    {"userfaultfd",
     323,
     NORMAL,
     {
             [ARG_0] = {"flags", 4},
     }},
    {"ustat",
     136,
     NORMAL,
     {
             [ARG_0] = {"dev", 4}, [ARG_1] = {"ubuf", 8},
     }},
    {"utime",
     132,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"times", 8},
     }},
    {"utimensat",
     280,
     NORMAL,
     {
             [ARG_0] = {"dfd", 4}, [ARG_1] = {"filename", 8},
             [ARG_2] = {"utimes", 8}, [ARG_3] = {"flags", 4},
     }},
    {"utimes",
     235,
     NORMAL,
     {
             [ARG_0] = {"filename", 8}, [ARG_1] = {"utimes", 8},
     }},
    {"vfork", 58, NORMAL, {}},
    {"vhangup", 153, NORMAL, {}},
    {"vmsplice",
     278,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"iov", 8},
             [ARG_2] = {"nr_segs", 8}, [ARG_3] = {"flags", 4},
     }},
    {"vserver", 236, NORMAL, {}},  // Unimplemented system call
    {"wait4",
     61,
     NORMAL,
     {
             [ARG_0] = {"upid", 4}, [ARG_1] = {"stat_addr", 8},
             [ARG_2] = {"options", 4}, [ARG_3] = {"ru", 8},
     }},
    {"waitid",
     247,
     NORMAL,
     {
             [ARG_0] = {"which", 4}, [ARG_1] = {"upid", 4},
             [ARG_2] = {"infop", 8}, [ARG_3] = {"options", 4},
             [ARG_4] = {"ru", 8},
     }},
    {"write",
     1,
     NORMAL,
     {
             [ARG_0] = {"fd", 4}, [ARG_1] = {"buf", 8}, [ARG_2] = {"count", 8},
     }},
    {"writev",
     20,
     NORMAL,
     {
             [ARG_0] = {"fd", 8}, [ARG_1] = {"vec", 8}, [ARG_2] = {"vlen", 8},
     }},
};

const size_t amd64_syscall_list_size =
    sizeof(amd64_syscall_list) / sizeof(amd64_syscall_list[0]);
