/*
   Kafel - syscalls (Intel 80386)
   -----------------------------------------

   Copyright 2016 Google Inc. All Rights Reserved.

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.

*/

#include "../syscall.h"

#include <stddef.h>

#define ARG_0 0
#define ARG_1 1
#define ARG_2 2
#define ARG_3 3
#define ARG_4 4
#define ARG_5 5

#define NORMAL false

const struct syscall_descriptor i386_syscall_list [] = {
    {"accept4",
     364,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"upeer_sockaddr", 4},
         [ARG_2] = {"upeer_addrlen", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"access",
     33,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"mode", 4},
     }},
    {"acct",
     51,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
     }},
    {"add_key",
     286,
     NORMAL,
     {
         [ARG_0] = {"_type", 4},
         [ARG_1] = {"_description", 4},
         [ARG_2] = {"_payload", 4},
         [ARG_3] = {"plen", 4},
         [ARG_4] = {"ringid", 4},
     }},
    {"adjtimex",
     124,
     NORMAL,
     {
         [ARG_0] = {"txc_p", 4},
     }},
    {"alarm",
     27,
     NORMAL,
     {
         [ARG_0] = {"seconds", 4},
     }},
    {"arch_prctl",
     384,
     NORMAL,
     {
         [ARG_0] = {"option", 4},
         [ARG_1] = {"arg2", 4},
     }},
    {"bdflush",
     134,
     NORMAL,
     {
         [ARG_0] = {"func", 4},
         [ARG_1] = {"data", 4},
     }},
    {"bind",
     361,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"umyaddr", 4},
         [ARG_2] = {"addrlen", 4},
     }},
    {"brk",
     45,
     NORMAL,
     {
         [ARG_0] = {"brk", 4},
     }},
    {"capget",
     184,
     NORMAL,
     {
         [ARG_0] = {"header", 4},
         [ARG_1] = {"dataptr", 4},
     }},
    {"capset",
     185,
     NORMAL,
     {
         [ARG_0] = {"header", 4},
         [ARG_1] = {"data", 4},
     }},
    {"chdir",
     12,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
     }},
    {"chmod",
     15,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"mode", 2},
     }},
    {"chown",
     212,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"user", 4},
         [ARG_2] = {"group", 4},
     }},
    {"chown16",
     182,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"user", 2},
         [ARG_2] = {"group", 2},
     }},
    {"chroot",
     61,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
     }},
    {"clock_adjtime",
     343,
     NORMAL,
     {
         [ARG_0] = {"which_clock", 4},
         [ARG_1] = {"utx", 4},
     }},
    {"clock_getres",
     266,
     NORMAL,
     {
         [ARG_0] = {"which_clock", 4},
         [ARG_1] = {"tp", 4},
     }},
    {"clock_gettime",
     265,
     NORMAL,
     {
         [ARG_0] = {"which_clock", 4},
         [ARG_1] = {"tp", 4},
     }},
    {"clock_nanosleep",
     267,
     NORMAL,
     {
         [ARG_0] = {"which_clock", 4},
         [ARG_1] = {"flags", 4},
         [ARG_2] = {"rqtp", 4},
         [ARG_3] = {"rmtp", 4},
     }},
    {"clock_settime",
     264,
     NORMAL,
     {
         [ARG_0] = {"which_clock", 4},
         [ARG_1] = {"tp", 4},
     }},
    {"clone",
     120,
     NORMAL,
     {
         [ARG_0] = {"clone_flags", 4},
         [ARG_1] = {"newsp", 4},
         [ARG_2] = {"parent_tidptr", 4},
         [ARG_3] = {"tls", 4},
         [ARG_4] = {"child_tidptr", 4},
     }},
    {"close",
     6,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
     }},
    {"connect",
     362,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"uservaddr", 4},
         [ARG_2] = {"addrlen", 4},
     }},
    {"copy_file_range",
     377,
     NORMAL,
     {
         [ARG_0] = {"fd_in", 4},
         [ARG_1] = {"off_in", 4},
         [ARG_2] = {"fd_out", 4},
         [ARG_3] = {"off_out", 4},
         [ARG_4] = {"len", 4},
         [ARG_5] = {"flags", 4},
     }},
    {"creat",
     8,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"mode", 2},
     }},
    {"delete_module",
     129,
     NORMAL,
     {
         [ARG_0] = {"name_user", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"dup",
     41,
     NORMAL,
     {
         [ARG_0] = {"fildes", 4},
     }},
    {"dup2",
     63,
     NORMAL,
     {
         [ARG_0] = {"oldfd", 4},
         [ARG_1] = {"newfd", 4},
     }},
    {"dup3",
     330,
     NORMAL,
     {
         [ARG_0] = {"oldfd", 4},
         [ARG_1] = {"newfd", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"epoll_create",
     254,
     NORMAL,
     {
         [ARG_0] = {"size", 4},
     }},
    {"epoll_create1",
     329,
     NORMAL,
     {
         [ARG_0] = {"flags", 4},
     }},
    {"epoll_ctl",
     255,
     NORMAL,
     {
         [ARG_0] = {"epfd", 4},
         [ARG_1] = {"op", 4},
         [ARG_2] = {"fd", 4},
         [ARG_3] = {"event", 4},
     }},
    {"epoll_pwait",
     319,
     NORMAL,
     {
         [ARG_0] = {"epfd", 4},
         [ARG_1] = {"events", 4},
         [ARG_2] = {"maxevents", 4},
         [ARG_3] = {"timeout", 4},
         [ARG_4] = {"sigmask", 4},
         [ARG_5] = {"sigsetsize", 4},
     }},
    {"epoll_wait",
     256,
     NORMAL,
     {
         [ARG_0] = {"epfd", 4},
         [ARG_1] = {"events", 4},
         [ARG_2] = {"maxevents", 4},
         [ARG_3] = {"timeout", 4},
     }},
    {"eventfd",
     323,
     NORMAL,
     {
         [ARG_0] = {"count", 4},
     }},
    {"eventfd2",
     328,
     NORMAL,
     {
         [ARG_0] = {"count", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"execve",
     11,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"argv", 4},
         [ARG_2] = {"envp", 4},
     }},
    {"execveat",
     358,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"argv", 4},
         [ARG_3] = {"envp", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"exit",
     1,
     NORMAL,
     {
         [ARG_0] = {"error_code", 4},
     }},
    {"exit_group",
     252,
     NORMAL,
     {
         [ARG_0] = {"error_code", 4},
     }},
    {"faccessat",
     307,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"mode", 4},
     }},
    {"fadvise64",
     250,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"offset", 8},
         [ARG_2] = {"len", 4},
         [ARG_3] = {"advice", 4},
     }},
    {"fadvise64_64",
     272,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"offset", 8},
         [ARG_2] = {"len", 8},
         [ARG_3] = {"advice", 4},
     }},
    {"fallocate",
     324,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"mode", 4},
         [ARG_2] = {"offset", 8},
         [ARG_3] = {"len", 8},
     }},
    {"fanotify_init",
     338,
     NORMAL,
     {
         [ARG_0] = {"flags", 4},
         [ARG_1] = {"event_f_flags", 4},
     }},
    {"fanotify_mark",
     339,
     NORMAL,
     {
         [ARG_0] = {"fanotify_fd", 4},
         [ARG_1] = {"flags", 4},
         [ARG_2] = {"mask", 8},
         [ARG_3] = {"dfd", 4},
         [ARG_4] = {"pathname", 4},
     }},
    {"fchdir",
     133,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
     }},
    {"fchmod",
     94,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"mode", 2},
     }},
    {"fchmodat",
     306,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"mode", 2},
     }},
    {"fchown",
     207,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"user", 4},
         [ARG_2] = {"group", 4},
     }},
    {"fchown16",
     95,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"user", 2},
         [ARG_2] = {"group", 2},
     }},
    {"fchownat",
     298,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"user", 4},
         [ARG_3] = {"group", 4},
         [ARG_4] = {"flag", 4},
     }},
    {"fcntl",
     55,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"cmd", 4},
         [ARG_2] = {"arg", 4},
     }},
    {"fcntl64",
     221,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"cmd", 4},
         [ARG_2] = {"arg", 4},
     }},
    {"fdatasync",
     148,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
     }},
    {"fgetxattr",
     231,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"value", 4},
         [ARG_3] = {"size", 4},
     }},
    {"finit_module",
     350,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"uargs", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"flistxattr",
     234,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"list", 4},
         [ARG_2] = {"size", 4},
     }},
    {"flock",
     143,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"cmd", 4},
     }},
    {"fork", 2, NORMAL, {}},
    {"fremovexattr",
     237,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"name", 4},
     }},
    {"fsetxattr",
     228,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"value", 4},
         [ARG_3] = {"size", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"fstat",
     28,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"fstat64",
     197,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"fstatat64",
     300,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"statbuf", 4},
         [ARG_3] = {"flag", 4},
     }},
    {"fstatfs",
     100,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"buf", 4},
     }},
    {"fstatfs64",
     269,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"sz", 4},
         [ARG_2] = {"buf", 4},
     }},
    {"fsync",
     118,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
     }},
    {"ftruncate",
     93,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"length", 4},
     }},
    {"ftruncate64",
     194,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"length", 8},
     }},
    {"futex",
     240,
     NORMAL,
     {
         [ARG_0] = {"uaddr", 4},
         [ARG_1] = {"op", 4},
         [ARG_2] = {"val", 4},
         [ARG_3] = {"utime", 4},
         [ARG_4] = {"uaddr2", 4},
         [ARG_5] = {"val3", 4},
     }},
    {"futimesat",
     299,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"utimes", 4},
     }},
    {"getcpu",
     318,
     NORMAL,
     {
         [ARG_0] = {"cpup", 4},
         [ARG_1] = {"nodep", 4},
         [ARG_2] = {"unused", 4},
     }},
    {"getcwd",
     183,
     NORMAL,
     {
         [ARG_0] = {"buf", 4},
         [ARG_1] = {"size", 4},
     }},
    {"getdents",
     141,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"dirent", 4},
         [ARG_2] = {"count", 4},
     }},
    {"getdents64",
     220,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"dirent", 4},
         [ARG_2] = {"count", 4},
     }},
    {"getegid", 202, NORMAL, {}},
    {"getegid16", 50, NORMAL, {}},
    {"geteuid", 201, NORMAL, {}},
    {"geteuid16", 49, NORMAL, {}},
    {"getgid", 200, NORMAL, {}},
    {"getgid16", 47, NORMAL, {}},
    {"getgroups",
     205,
     NORMAL,
     {
         [ARG_0] = {"gidsetsize", 4},
         [ARG_1] = {"grouplist", 4},
     }},
    {"getgroups16",
     80,
     NORMAL,
     {
         [ARG_0] = {"gidsetsize", 4},
         [ARG_1] = {"grouplist", 4},
     }},
    {"getitimer",
     105,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"value", 4},
     }},
    {"getpeername",
     368,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"usockaddr", 4},
         [ARG_2] = {"usockaddr_len", 4},
     }},
    {"getpgid",
     132,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
     }},
    {"getpgrp", 65, NORMAL, {}},
    {"getpid", 20, NORMAL, {}},
    {"getppid", 64, NORMAL, {}},
    {"getpriority",
     96,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"who", 4},
     }},
    {"getrandom",
     355,
     NORMAL,
     {
         [ARG_0] = {"buf", 4},
         [ARG_1] = {"count", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"getresgid",
     211,
     NORMAL,
     {
         [ARG_0] = {"rgidp", 4},
         [ARG_1] = {"egidp", 4},
         [ARG_2] = {"sgidp", 4},
     }},
    {"getresgid16",
     171,
     NORMAL,
     {
         [ARG_0] = {"rgidp", 4},
         [ARG_1] = {"egidp", 4},
         [ARG_2] = {"sgidp", 4},
     }},
    {"getresuid",
     209,
     NORMAL,
     {
         [ARG_0] = {"ruidp", 4},
         [ARG_1] = {"euidp", 4},
         [ARG_2] = {"suidp", 4},
     }},
    {"getresuid16",
     165,
     NORMAL,
     {
         [ARG_0] = {"ruidp", 4},
         [ARG_1] = {"euidp", 4},
         [ARG_2] = {"suidp", 4},
     }},
    {"getrlimit",
     191,
     NORMAL,
     {
         [ARG_0] = {"resource", 4},
         [ARG_1] = {"rlim", 4},
     }},
    {"get_robust_list",
     312,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"head_ptr", 4},
         [ARG_2] = {"len_ptr", 4},
     }},
    {"getrusage",
     77,
     NORMAL,
     {
         [ARG_0] = {"who", 4},
         [ARG_1] = {"ru", 4},
     }},
    {"getsid",
     147,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
     }},
    {"getsockname",
     367,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"usockaddr", 4},
         [ARG_2] = {"usockaddr_len", 4},
     }},
    {"getsockopt",
     365,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"level", 4},
         [ARG_2] = {"optname", 4},
         [ARG_3] = {"optval", 4},
         [ARG_4] = {"optlen", 4},
     }},
    {"get_thread_area",
     244,
     NORMAL,
     {
         [ARG_0] = {"u_info", 4},
     }},
    {"gettid", 224, NORMAL, {}},
    {"gettimeofday",
     78,
     NORMAL,
     {
         [ARG_0] = {"tv", 4},
         [ARG_1] = {"tz", 4},
     }},
    {"getuid", 199, NORMAL, {}},
    {"getuid16", 24, NORMAL, {}},
    {"getxattr",
     229,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"value", 4},
         [ARG_3] = {"size", 4},
     }},
    {"init_module",
     128,
     NORMAL,
     {
         [ARG_0] = {"umod", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"uargs", 4},
     }},
    {"inotify_add_watch",
     292,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"pathname", 4},
         [ARG_2] = {"mask", 4},
     }},
    {"inotify_init", 291, NORMAL, {}},
    {"inotify_init1",
     332,
     NORMAL,
     {
         [ARG_0] = {"flags", 4},
     }},
    {"inotify_rm_watch",
     293,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"wd", 4},
     }},
    {"io_cancel",
     249,
     NORMAL,
     {
         [ARG_0] = {"ctx_id", 4},
         [ARG_1] = {"iocb", 4},
         [ARG_2] = {"result", 4},
     }},
    {"ioctl",
     54,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"cmd", 4},
         [ARG_2] = {"arg", 4},
     }},
    {"io_destroy",
     246,
     NORMAL,
     {
         [ARG_0] = {"ctx", 4},
     }},
    {"io_getevents",
     247,
     NORMAL,
     {
         [ARG_0] = {"ctx_id", 4},
         [ARG_1] = {"min_nr", 4},
         [ARG_2] = {"nr", 4},
         [ARG_3] = {"events", 4},
         [ARG_4] = {"timeout", 4},
     }},
    {"ioperm",
     101,
     NORMAL,
     {
         [ARG_0] = {"from", 4},
         [ARG_1] = {"num", 4},
         [ARG_2] = {"turn_on", 4},
     }},
    {"iopl",
     110,
     NORMAL,
     {
         [ARG_0] = {"level", 4},
     }},
    {"ioprio_get",
     290,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"who", 4},
     }},
    {"ioprio_set",
     289,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"who", 4},
         [ARG_2] = {"ioprio", 4},
     }},
    {"io_setup",
     245,
     NORMAL,
     {
         [ARG_0] = {"nr_events", 4},
         [ARG_1] = {"ctxp", 4},
     }},
    {"io_submit",
     248,
     NORMAL,
     {
         [ARG_0] = {"ctx_id", 4},
         [ARG_1] = {"nr", 4},
         [ARG_2] = {"iocbpp", 4},
     }},
    {"ipc",
     117,
     NORMAL,
     {
         [ARG_0] = {"call", 4},
         [ARG_1] = {"first", 4},
         [ARG_2] = {"second", 4},
         [ARG_3] = {"third", 4},
         [ARG_4] = {"ptr", 4},
         [ARG_5] = {"fifth", 4},
     }},
    {"kexec_load",
     283,
     NORMAL,
     {
         [ARG_0] = {"entry", 4},
         [ARG_1] = {"nr_segments", 4},
         [ARG_2] = {"segments", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"keyctl",
     288,
     NORMAL,
     {
         [ARG_0] = {"option", 4},
         [ARG_1] = {"arg2", 4},
         [ARG_2] = {"arg3", 4},
         [ARG_3] = {"arg4", 4},
         [ARG_4] = {"arg5", 4},
     }},
    {"kill",
     37,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"sig", 4},
     }},
    {"lchown",
     198,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"user", 4},
         [ARG_2] = {"group", 4},
     }},
    {"lchown16",
     16,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"user", 2},
         [ARG_2] = {"group", 2},
     }},
    {"lgetxattr",
     230,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"value", 4},
         [ARG_3] = {"size", 4},
     }},
    {"link",
     9,
     NORMAL,
     {
         [ARG_0] = {"oldname", 4},
         [ARG_1] = {"newname", 4},
     }},
    {"linkat",
     303,
     NORMAL,
     {
         [ARG_0] = {"olddfd", 4},
         [ARG_1] = {"oldname", 4},
         [ARG_2] = {"newdfd", 4},
         [ARG_3] = {"newname", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"listen",
     363,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"backlog", 4},
     }},
    {"listxattr",
     232,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"list", 4},
         [ARG_2] = {"size", 4},
     }},
    {"llistxattr",
     233,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"list", 4},
         [ARG_2] = {"size", 4},
     }},
    {"llseek",
     140,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"offset_high", 4},
         [ARG_2] = {"offset_low", 4},
         [ARG_3] = {"result", 4},
         [ARG_4] = {"whence", 4},
     }},
    {"lookup_dcookie",
     253,
     NORMAL,
     {
         [ARG_0] = {"cookie64", 8},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"len", 4},
     }},
    {"lremovexattr",
     236,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"name", 4},
     }},
    {"lseek",
     19,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"offset", 4},
         [ARG_2] = {"whence", 4},
     }},
    {"lsetxattr",
     227,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"value", 4},
         [ARG_3] = {"size", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"lstat",
     84,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"lstat64",
     196,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"madvise",
     219,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len_in", 4},
         [ARG_2] = {"behavior", 4},
     }},
    {"membarrier",
     375,
     NORMAL,
     {
         [ARG_0] = {"cmd", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"memfd_create",
     356,
     NORMAL,
     {
         [ARG_0] = {"uname", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"mincore",
     218,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"vec", 4},
     }},
    {"mkdir",
     39,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"mode", 2},
     }},
    {"mkdirat",
     296,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"pathname", 4},
         [ARG_2] = {"mode", 2},
     }},
    {"mknod",
     14,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"mode", 2},
         [ARG_2] = {"dev", 4},
     }},
    {"mknodat",
     297,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"mode", 2},
         [ARG_3] = {"dev", 4},
     }},
    {"mlock",
     150,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len", 4},
     }},
    {"mlock2",
     376,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"mlockall",
     152,
     NORMAL,
     {
         [ARG_0] = {"flags", 4},
     }},
    {"mmap_pgoff",
     192,
     NORMAL,
     {
         [ARG_0] = {"addr", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"prot", 4},
         [ARG_3] = {"flags", 4},
         [ARG_4] = {"fd", 4},
         [ARG_5] = {"pgoff", 4},
     }},
    {"modify_ldt",
     123,
     NORMAL,
     {
         [ARG_0] = {"func", 4},
         [ARG_1] = {"ptr", 4},
         [ARG_2] = {"bytecount", 4},
     }},
    {"mount",
     21,
     NORMAL,
     {
         [ARG_0] = {"dev_name", 4},
         [ARG_1] = {"dir_name", 4},
         [ARG_2] = {"type", 4},
         [ARG_3] = {"flags", 4},
         [ARG_4] = {"data", 4},
     }},
    {"mprotect",
     125,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"prot", 4},
     }},
    {"mq_getsetattr",
     282,
     NORMAL,
     {
         [ARG_0] = {"mqdes", 4},
         [ARG_1] = {"u_mqstat", 4},
         [ARG_2] = {"u_omqstat", 4},
     }},
    {"mq_notify",
     281,
     NORMAL,
     {
         [ARG_0] = {"mqdes", 4},
         [ARG_1] = {"u_notification", 4},
     }},
    {"mq_open",
     277,
     NORMAL,
     {
         [ARG_0] = {"u_name", 4},
         [ARG_1] = {"oflag", 4},
         [ARG_2] = {"mode", 2},
         [ARG_3] = {"u_attr", 4},
     }},
    {"mq_timedreceive",
     280,
     NORMAL,
     {
         [ARG_0] = {"mqdes", 4},
         [ARG_1] = {"u_msg_ptr", 4},
         [ARG_2] = {"msg_len", 4},
         [ARG_3] = {"u_msg_prio", 4},
         [ARG_4] = {"u_abs_timeout", 4},
     }},
    {"mq_timedsend",
     279,
     NORMAL,
     {
         [ARG_0] = {"mqdes", 4},
         [ARG_1] = {"u_msg_ptr", 4},
         [ARG_2] = {"msg_len", 4},
         [ARG_3] = {"msg_prio", 4},
         [ARG_4] = {"u_abs_timeout", 4},
     }},
    {"mq_unlink",
     278,
     NORMAL,
     {
         [ARG_0] = {"u_name", 4},
     }},
    {"mremap",
     163,
     NORMAL,
     {
         [ARG_0] = {"addr", 4},
         [ARG_1] = {"old_len", 4},
         [ARG_2] = {"new_len", 4},
         [ARG_3] = {"flags", 4},
         [ARG_4] = {"new_addr", 4},
     }},
    {"msync",
     144,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"munlock",
     151,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"len", 4},
     }},
    {"munlockall", 153, NORMAL, {}},
    {"munmap",
     91,
     NORMAL,
     {
         [ARG_0] = {"addr", 4},
         [ARG_1] = {"len", 4},
     }},
    {"name_to_handle_at",
     341,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"handle", 4},
         [ARG_3] = {"mnt_id", 4},
         [ARG_4] = {"flag", 4},
     }},
    {"nanosleep",
     162,
     NORMAL,
     {
         [ARG_0] = {"rqtp", 4},
         [ARG_1] = {"rmtp", 4},
     }},
    {"newfstat",
     108,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"newlstat",
     107,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"newstat",
     106,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"newuname",
     122,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
     }},
    {"nice",
     34,
     NORMAL,
     {
         [ARG_0] = {"increment", 4},
     }},
    {"old_getrlimit",
     76,
     NORMAL,
     {
         [ARG_0] = {"resource", 4},
         [ARG_1] = {"rlim", 4},
     }},
    {"old_mmap",
     90,
     NORMAL,
     {
         [ARG_0] = {"arg", 4},
     }},
    {"old_readdir",
     89,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"dirent", 4},
         [ARG_2] = {"count", 4},
     }},
    {"old_select",
     82,
     NORMAL,
     {
         [ARG_0] = {"arg", 4},
     }},
    {"oldumount",
     22,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
     }},
    {"olduname",
     59,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
     }},
    {"open",
     5,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"flags", 4},
         [ARG_2] = {"mode", 2},
     }},
    {"openat",
     295,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"flags", 4},
         [ARG_3] = {"mode", 2},
     }},
    {"open_by_handle_at",
     342,
     NORMAL,
     {
         [ARG_0] = {"mountdirfd", 4},
         [ARG_1] = {"handle", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"pause", 29, NORMAL, {}},
    {"perf_event_open",
     336,
     NORMAL,
     {
         [ARG_0] = {"attr_uptr", 4},
         [ARG_1] = {"pid", 4},
         [ARG_2] = {"cpu", 4},
         [ARG_3] = {"group_fd", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"personality",
     136,
     NORMAL,
     {
         [ARG_0] = {"personality", 4},
     }},
    {"pipe",
     42,
     NORMAL,
     {
         [ARG_0] = {"fildes", 4},
     }},
    {"pipe2",
     331,
     NORMAL,
     {
         [ARG_0] = {"fildes", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"pivot_root",
     217,
     NORMAL,
     {
         [ARG_0] = {"new_root", 4},
         [ARG_1] = {"put_old", 4},
     }},
    {"poll",
     168,
     NORMAL,
     {
         [ARG_0] = {"ufds", 4},
         [ARG_1] = {"nfds", 4},
         [ARG_2] = {"timeout_msecs", 4},
     }},
    {"ppoll",
     309,
     NORMAL,
     {
         [ARG_0] = {"ufds", 4},
         [ARG_1] = {"nfds", 4},
         [ARG_2] = {"tsp", 4},
         [ARG_3] = {"sigmask", 4},
         [ARG_4] = {"sigsetsize", 4},
     }},
    {"prctl",
     172,
     NORMAL,
     {
         [ARG_0] = {"option", 4},
         [ARG_1] = {"arg2", 4},
         [ARG_2] = {"arg3", 4},
         [ARG_3] = {"arg4", 4},
         [ARG_4] = {"arg5", 4},
     }},
    {"pread64",
     180,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"count", 4},
         [ARG_3] = {"pos", 8},
     }},
    {"preadv",
     333,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"vec", 4},
         [ARG_2] = {"vlen", 4},
         [ARG_3] = {"pos_l", 4},
         [ARG_4] = {"pos_h", 4},
     }},
    {"preadv2",
     378,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"vec", 4},
         [ARG_2] = {"vlen", 4},
         [ARG_3] = {"pos_l", 4},
         [ARG_4] = {"pos_h", 4},
         [ARG_5] = {"flags", 4},
     }},
    {"prlimit64",
     340,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"resource", 4},
         [ARG_2] = {"new_rlim", 4},
         [ARG_3] = {"old_rlim", 4},
     }},
    {"process_vm_readv",
     347,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"lvec", 4},
         [ARG_2] = {"liovcnt", 4},
         [ARG_3] = {"rvec", 4},
         [ARG_4] = {"riovcnt", 4},
         [ARG_5] = {"flags", 4},
     }},
    {"process_vm_writev",
     348,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"lvec", 4},
         [ARG_2] = {"liovcnt", 4},
         [ARG_3] = {"rvec", 4},
         [ARG_4] = {"riovcnt", 4},
         [ARG_5] = {"flags", 4},
     }},
    {"pselect6",
     308,
     NORMAL,
     {
         [ARG_0] = {"n", 4},
         [ARG_1] = {"inp", 4},
         [ARG_2] = {"outp", 4},
         [ARG_3] = {"exp", 4},
         [ARG_4] = {"tsp", 4},
         [ARG_5] = {"sig", 4},
     }},
    {"ptrace",
     26,
     NORMAL,
     {
         [ARG_0] = {"request", 4},
         [ARG_1] = {"pid", 4},
         [ARG_2] = {"addr", 4},
         [ARG_3] = {"data", 4},
     }},
    {"pwrite64",
     181,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"count", 4},
         [ARG_3] = {"pos", 8},
     }},
    {"pwritev",
     334,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"vec", 4},
         [ARG_2] = {"vlen", 4},
         [ARG_3] = {"pos_l", 4},
         [ARG_4] = {"pos_h", 4},
     }},
    {"pwritev2",
     379,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"vec", 4},
         [ARG_2] = {"vlen", 4},
         [ARG_3] = {"pos_l", 4},
         [ARG_4] = {"pos_h", 4},
         [ARG_5] = {"flags", 4},
     }},
    {"quotactl",
     131,
     NORMAL,
     {
         [ARG_0] = {"cmd", 4},
         [ARG_1] = {"special", 4},
         [ARG_2] = {"id", 4},
         [ARG_3] = {"addr", 4},
     }},
    {"read",
     3,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"count", 4},
     }},
    {"readahead",
     225,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"offset", 8},
         [ARG_2] = {"count", 4},
     }},
    {"readlink",
     85,
     NORMAL,
     {
         [ARG_0] = {"path", 4},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"bufsiz", 4},
     }},
    {"readlinkat",
     305,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"pathname", 4},
         [ARG_2] = {"buf", 4},
         [ARG_3] = {"bufsiz", 4},
     }},
    {"readv",
     145,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"vec", 4},
         [ARG_2] = {"vlen", 4},
     }},
    {"reboot",
     88,
     NORMAL,
     {
         [ARG_0] = {"magic1", 4},
         [ARG_1] = {"magic2", 4},
         [ARG_2] = {"cmd", 4},
         [ARG_3] = {"arg", 4},
     }},
    {"recvfrom",
     371,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"ubuf", 4},
         [ARG_2] = {"size", 4},
         [ARG_3] = {"flags", 4},
         [ARG_4] = {"addr", 4},
         [ARG_5] = {"addr_len", 4},
     }},
    {"recvmmsg",
     337,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"mmsg", 4},
         [ARG_2] = {"vlen", 4},
         [ARG_3] = {"flags", 4},
         [ARG_4] = {"timeout", 4},
     }},
    {"recvmsg",
     372,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"msg", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"remap_file_pages",
     257,
     NORMAL,
     {
         [ARG_0] = {"start", 4},
         [ARG_1] = {"size", 4},
         [ARG_2] = {"prot", 4},
         [ARG_3] = {"pgoff", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"removexattr",
     235,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"name", 4},
     }},
    {"rename",
     38,
     NORMAL,
     {
         [ARG_0] = {"oldname", 4},
         [ARG_1] = {"newname", 4},
     }},
    {"renameat",
     302,
     NORMAL,
     {
         [ARG_0] = {"olddfd", 4},
         [ARG_1] = {"oldname", 4},
         [ARG_2] = {"newdfd", 4},
         [ARG_3] = {"newname", 4},
     }},
    {"renameat2",
     353,
     NORMAL,
     {
         [ARG_0] = {"olddfd", 4},
         [ARG_1] = {"oldname", 4},
         [ARG_2] = {"newdfd", 4},
         [ARG_3] = {"newname", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"request_key",
     287,
     NORMAL,
     {
         [ARG_0] = {"_type", 4},
         [ARG_1] = {"_description", 4},
         [ARG_2] = {"_callout_info", 4},
         [ARG_3] = {"destringid", 4},
     }},
    {"restart_syscall", 0, NORMAL, {}},
    {"rmdir",
     40,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
     }},
    {"rt_sigaction",
     174,
     NORMAL,
     {
         [ARG_0] = {"sig", 4},
         [ARG_1] = {"act", 4},
         [ARG_2] = {"oact", 4},
         [ARG_3] = {"sigsetsize", 4},
     }},
    {"rt_sigpending",
     176,
     NORMAL,
     {
         [ARG_0] = {"uset", 4},
         [ARG_1] = {"sigsetsize", 4},
     }},
    {"rt_sigprocmask",
     175,
     NORMAL,
     {
         [ARG_0] = {"how", 4},
         [ARG_1] = {"nset", 4},
         [ARG_2] = {"oset", 4},
         [ARG_3] = {"sigsetsize", 4},
     }},
    {"rt_sigqueueinfo",
     178,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"sig", 4},
         [ARG_2] = {"uinfo", 4},
     }},
    {"rt_sigsuspend",
     179,
     NORMAL,
     {
         [ARG_0] = {"unewset", 4},
         [ARG_1] = {"sigsetsize", 4},
     }},
    {"rt_sigtimedwait",
     177,
     NORMAL,
     {
         [ARG_0] = {"uthese", 4},
         [ARG_1] = {"uinfo", 4},
         [ARG_2] = {"uts", 4},
         [ARG_3] = {"sigsetsize", 4},
     }},
    {"rt_tgsigqueueinfo",
     335,
     NORMAL,
     {
         [ARG_0] = {"tgid", 4},
         [ARG_1] = {"pid", 4},
         [ARG_2] = {"sig", 4},
         [ARG_3] = {"uinfo", 4},
     }},
    {"sched_getaffinity",
     242,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"user_mask_ptr", 4},
     }},
    {"sched_getattr",
     352,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"uattr", 4},
         [ARG_2] = {"size", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"sched_getparam",
     155,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"param", 4},
     }},
    {"sched_get_priority_max",
     159,
     NORMAL,
     {
         [ARG_0] = {"policy", 4},
     }},
    {"sched_get_priority_min",
     160,
     NORMAL,
     {
         [ARG_0] = {"policy", 4},
     }},
    {"sched_getscheduler",
     157,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
     }},
    {"sched_rr_get_interval",
     161,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"interval", 4},
     }},
    {"sched_setaffinity",
     241,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"len", 4},
         [ARG_2] = {"user_mask_ptr", 4},
     }},
    {"sched_setattr",
     351,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"uattr", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"sched_setparam",
     154,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"param", 4},
     }},
    {"sched_setscheduler",
     156,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"policy", 4},
         [ARG_2] = {"param", 4},
     }},
    {"sched_yield", 158, NORMAL, {}},
    {"seccomp",
     354,
     NORMAL,
     {
         [ARG_0] = {"op", 4},
         [ARG_1] = {"flags", 4},
         [ARG_2] = {"uargs", 4},
     }},
    {"select",
     142,
     NORMAL,
     {
         [ARG_0] = {"n", 4},
         [ARG_1] = {"inp", 4},
         [ARG_2] = {"outp", 4},
         [ARG_3] = {"exp", 4},
         [ARG_4] = {"tvp", 4},
     }},
    {"sendfile",
     187,
     NORMAL,
     {
         [ARG_0] = {"out_fd", 4},
         [ARG_1] = {"in_fd", 4},
         [ARG_2] = {"offset", 4},
         [ARG_3] = {"count", 4},
     }},
    {"sendfile64",
     239,
     NORMAL,
     {
         [ARG_0] = {"out_fd", 4},
         [ARG_1] = {"in_fd", 4},
         [ARG_2] = {"offset", 4},
         [ARG_3] = {"count", 4},
     }},
    {"sendmmsg",
     345,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"mmsg", 4},
         [ARG_2] = {"vlen", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"sendmsg",
     370,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"msg", 4},
         [ARG_2] = {"flags", 4},
     }},
    {"sendto",
     369,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"buff", 4},
         [ARG_2] = {"len", 4},
         [ARG_3] = {"flags", 4},
         [ARG_4] = {"addr", 4},
         [ARG_5] = {"addr_len", 4},
     }},
    {"setdomainname",
     121,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
         [ARG_1] = {"len", 4},
     }},
    {"setfsgid",
     216,
     NORMAL,
     {
         [ARG_0] = {"gid", 4},
     }},
    {"setfsgid16",
     139,
     NORMAL,
     {
         [ARG_0] = {"gid", 2},
     }},
    {"setfsuid",
     215,
     NORMAL,
     {
         [ARG_0] = {"uid", 4},
     }},
    {"setfsuid16",
     138,
     NORMAL,
     {
         [ARG_0] = {"uid", 2},
     }},
    {"setgid",
     214,
     NORMAL,
     {
         [ARG_0] = {"gid", 4},
     }},
    {"setgid16",
     46,
     NORMAL,
     {
         [ARG_0] = {"gid", 2},
     }},
    {"setgroups",
     206,
     NORMAL,
     {
         [ARG_0] = {"gidsetsize", 4},
         [ARG_1] = {"grouplist", 4},
     }},
    {"setgroups16",
     81,
     NORMAL,
     {
         [ARG_0] = {"gidsetsize", 4},
         [ARG_1] = {"grouplist", 4},
     }},
    {"sethostname",
     74,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
         [ARG_1] = {"len", 4},
     }},
    {"setitimer",
     104,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"value", 4},
         [ARG_2] = {"ovalue", 4},
     }},
    {"setns",
     346,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"nstype", 4},
     }},
    {"setpgid",
     57,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"pgid", 4},
     }},
    {"setpriority",
     97,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"who", 4},
         [ARG_2] = {"niceval", 4},
     }},
    {"setregid",
     204,
     NORMAL,
     {
         [ARG_0] = {"rgid", 4},
         [ARG_1] = {"egid", 4},
     }},
    {"setregid16",
     71,
     NORMAL,
     {
         [ARG_0] = {"rgid", 2},
         [ARG_1] = {"egid", 2},
     }},
    {"setresgid",
     210,
     NORMAL,
     {
         [ARG_0] = {"rgid", 4},
         [ARG_1] = {"egid", 4},
         [ARG_2] = {"sgid", 4},
     }},
    {"setresgid16",
     170,
     NORMAL,
     {
         [ARG_0] = {"rgid", 2},
         [ARG_1] = {"egid", 2},
         [ARG_2] = {"sgid", 2},
     }},
    {"setresuid",
     208,
     NORMAL,
     {
         [ARG_0] = {"ruid", 4},
         [ARG_1] = {"euid", 4},
         [ARG_2] = {"suid", 4},
     }},
    {"setresuid16",
     164,
     NORMAL,
     {
         [ARG_0] = {"ruid", 2},
         [ARG_1] = {"euid", 2},
         [ARG_2] = {"suid", 2},
     }},
    {"setreuid",
     203,
     NORMAL,
     {
         [ARG_0] = {"ruid", 4},
         [ARG_1] = {"euid", 4},
     }},
    {"setreuid16",
     70,
     NORMAL,
     {
         [ARG_0] = {"ruid", 2},
         [ARG_1] = {"euid", 2},
     }},
    {"setrlimit",
     75,
     NORMAL,
     {
         [ARG_0] = {"resource", 4},
         [ARG_1] = {"rlim", 4},
     }},
    {"set_robust_list",
     311,
     NORMAL,
     {
         [ARG_0] = {"head", 4},
         [ARG_1] = {"len", 4},
     }},
    {"setsid", 66, NORMAL, {}},
    {"setsockopt",
     366,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"level", 4},
         [ARG_2] = {"optname", 4},
         [ARG_3] = {"optval", 4},
         [ARG_4] = {"optlen", 4},
     }},
    {"set_thread_area",
     243,
     NORMAL,
     {
         [ARG_0] = {"u_info", 4},
     }},
    {"set_tid_address",
     258,
     NORMAL,
     {
         [ARG_0] = {"tidptr", 4},
     }},
    {"settimeofday",
     79,
     NORMAL,
     {
         [ARG_0] = {"tv", 4},
         [ARG_1] = {"tz", 4},
     }},
    {"setuid",
     213,
     NORMAL,
     {
         [ARG_0] = {"uid", 4},
     }},
    {"setuid16",
     23,
     NORMAL,
     {
         [ARG_0] = {"uid", 2},
     }},
    {"setxattr",
     226,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"name", 4},
         [ARG_2] = {"value", 4},
         [ARG_3] = {"size", 4},
         [ARG_4] = {"flags", 4},
     }},
    {"sgetmask", 68, NORMAL, {}},
    {"shutdown",
     373,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"how", 4},
     }},
    {"sigaction",
     67,
     NORMAL,
     {
         [ARG_0] = {"sig", 4},
         [ARG_1] = {"act", 4},
         [ARG_2] = {"oact", 4},
     }},
    {"sigaltstack",
     186,
     NORMAL,
     {
         [ARG_0] = {"uss", 4},
         [ARG_1] = {"uoss", 4},
     }},
    {"signal",
     48,
     NORMAL,
     {
         [ARG_0] = {"sig", 4},
         [ARG_1] = {"handler", 4},
     }},
    {"signalfd",
     321,
     NORMAL,
     {
         [ARG_0] = {"ufd", 4},
         [ARG_1] = {"user_mask", 4},
         [ARG_2] = {"sizemask", 4},
     }},
    {"signalfd4",
     327,
     NORMAL,
     {
         [ARG_0] = {"ufd", 4},
         [ARG_1] = {"user_mask", 4},
         [ARG_2] = {"sizemask", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"sigpending",
     73,
     NORMAL,
     {
         [ARG_0] = {"set", 4},
     }},
    {"sigprocmask",
     126,
     NORMAL,
     {
         [ARG_0] = {"how", 4},
         [ARG_1] = {"nset", 4},
         [ARG_2] = {"oset", 4},
     }},
    {"sigsuspend",
     72,
     NORMAL,
     {
         [ARG_0] = {"unused1", 4},
         [ARG_1] = {"unused2", 4},
         [ARG_2] = {"mask", 4},
     }},
    {"socket",
     359,
     NORMAL,
     {
         [ARG_0] = {"family", 4},
         [ARG_1] = {"type", 4},
         [ARG_2] = {"protocol", 4},
     }},
    {"socketcall",
     102,
     NORMAL,
     {
         [ARG_0] = {"call", 4},
         [ARG_1] = {"args", 4},
     }},
    {"socketpair",
     360,
     NORMAL,
     {
         [ARG_0] = {"family", 4},
         [ARG_1] = {"type", 4},
         [ARG_2] = {"protocol", 4},
         [ARG_3] = {"usockvec", 4},
     }},
    {"splice",
     313,
     NORMAL,
     {
         [ARG_0] = {"fd_in", 4},
         [ARG_1] = {"off_in", 4},
         [ARG_2] = {"fd_out", 4},
         [ARG_3] = {"off_out", 4},
         [ARG_4] = {"len", 4},
         [ARG_5] = {"flags", 4},
     }},
    {"ssetmask",
     69,
     NORMAL,
     {
         [ARG_0] = {"newmask", 4},
     }},
    {"stat",
     18,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"stat64",
     195,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"statbuf", 4},
     }},
    {"statfs",
     99,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"buf", 4},
     }},
    {"statfs64",
     268,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
         [ARG_1] = {"sz", 4},
         [ARG_2] = {"buf", 4},
     }},
    {"statx",
     383,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"flags", 4},
         [ARG_3] = {"mask", 4},
         [ARG_4] = {"buffer", 4},
     }},
    {"stime",
     25,
     NORMAL,
     {
         [ARG_0] = {"tptr", 4},
     }},
    {"swapoff",
     115,
     NORMAL,
     {
         [ARG_0] = {"specialfile", 4},
     }},
    {"swapon",
     87,
     NORMAL,
     {
         [ARG_0] = {"specialfile", 4},
         [ARG_1] = {"swap_flags", 4},
     }},
    {"symlink",
     83,
     NORMAL,
     {
         [ARG_0] = {"oldname", 4},
         [ARG_1] = {"newname", 4},
     }},
    {"symlinkat",
     304,
     NORMAL,
     {
         [ARG_0] = {"oldname", 4},
         [ARG_1] = {"newdfd", 4},
         [ARG_2] = {"newname", 4},
     }},
    {"sync", 36, NORMAL, {}},
    {"sync_file_range",
     314,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"offset", 8},
         [ARG_2] = {"nbytes", 8},
         [ARG_3] = {"flags", 4},
     }},
    {"syncfs",
     344,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
     }},
    {"sysctl",
     149,
     NORMAL,
     {
         [ARG_0] = {"args", 4},
     }},
    {"sysfs",
     135,
     NORMAL,
     {
         [ARG_0] = {"option", 4},
         [ARG_1] = {"arg1", 4},
         [ARG_2] = {"arg2", 4},
     }},
    {"sysinfo",
     116,
     NORMAL,
     {
         [ARG_0] = {"info", 4},
     }},
    {"syslog",
     103,
     NORMAL,
     {
         [ARG_0] = {"type", 4},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"len", 4},
     }},
    {"tee",
     315,
     NORMAL,
     {
         [ARG_0] = {"fdin", 4},
         [ARG_1] = {"fdout", 4},
         [ARG_2] = {"len", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"tgkill",
     270,
     NORMAL,
     {
         [ARG_0] = {"tgid", 4},
         [ARG_1] = {"pid", 4},
         [ARG_2] = {"sig", 4},
     }},
    {"time",
     13,
     NORMAL,
     {
         [ARG_0] = {"tloc", 4},
     }},
    {"timer_create",
     259,
     NORMAL,
     {
         [ARG_0] = {"which_clock", 4},
         [ARG_1] = {"timer_event_spec", 4},
         [ARG_2] = {"created_timer_id", 4},
     }},
    {"timer_delete",
     263,
     NORMAL,
     {
         [ARG_0] = {"timer_id", 4},
     }},
    {"timerfd_create",
     322,
     NORMAL,
     {
         [ARG_0] = {"clockid", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"timerfd_gettime",
     326,
     NORMAL,
     {
         [ARG_0] = {"ufd", 4},
         [ARG_1] = {"otmr", 4},
     }},
    {"timerfd_settime",
     325,
     NORMAL,
     {
         [ARG_0] = {"ufd", 4},
         [ARG_1] = {"flags", 4},
         [ARG_2] = {"utmr", 4},
         [ARG_3] = {"otmr", 4},
     }},
    {"timer_getoverrun",
     262,
     NORMAL,
     {
         [ARG_0] = {"timer_id", 4},
     }},
    {"timer_gettime",
     261,
     NORMAL,
     {
         [ARG_0] = {"timer_id", 4},
         [ARG_1] = {"setting", 4},
     }},
    {"timer_settime",
     260,
     NORMAL,
     {
         [ARG_0] = {"timer_id", 4},
         [ARG_1] = {"flags", 4},
         [ARG_2] = {"new_setting", 4},
         [ARG_3] = {"old_setting", 4},
     }},
    {"times",
     43,
     NORMAL,
     {
         [ARG_0] = {"tbuf", 4},
     }},
    {"tkill",
     238,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"sig", 4},
     }},
    {"truncate",
     92,
     NORMAL,
     {
         [ARG_0] = {"path", 4},
         [ARG_1] = {"length", 4},
     }},
    {"truncate64",
     193,
     NORMAL,
     {
         [ARG_0] = {"path", 4},
         [ARG_1] = {"length", 8},
     }},
    {"umask",
     60,
     NORMAL,
     {
         [ARG_0] = {"mask", 4},
     }},
    {"umount",
     52,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
         [ARG_1] = {"flags", 4},
     }},
    {"uname",
     109,
     NORMAL,
     {
         [ARG_0] = {"name", 4},
     }},
    {"unlink",
     10,
     NORMAL,
     {
         [ARG_0] = {"pathname", 4},
     }},
    {"unlinkat",
     301,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"pathname", 4},
         [ARG_2] = {"flag", 4},
     }},
    {"unshare",
     310,
     NORMAL,
     {
         [ARG_0] = {"unshare_flags", 4},
     }},
    {"ustat",
     62,
     NORMAL,
     {
         [ARG_0] = {"dev", 4},
         [ARG_1] = {"ubuf", 4},
     }},
    {"utime",
     30,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"times", 4},
     }},
    {"utimensat",
     320,
     NORMAL,
     {
         [ARG_0] = {"dfd", 4},
         [ARG_1] = {"filename", 4},
         [ARG_2] = {"utimes", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"utimes",
     271,
     NORMAL,
     {
         [ARG_0] = {"filename", 4},
         [ARG_1] = {"utimes", 4},
     }},
    {"vfork", 190, NORMAL, {}},
    {"vhangup", 111, NORMAL, {}},
    {"vm86",
     166,
     NORMAL,
     {
         [ARG_0] = {"cmd", 4},
         [ARG_1] = {"arg", 4},
     }},
    {"vm86old",
     113,
     NORMAL,
     {
         [ARG_0] = {"user_vm86", 4},
     }},
    {"vmsplice",
     316,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"iov", 4},
         [ARG_2] = {"nr_segs", 4},
         [ARG_3] = {"flags", 4},
     }},
    {"wait4",
     114,
     NORMAL,
     {
         [ARG_0] = {"upid", 4},
         [ARG_1] = {"stat_addr", 4},
         [ARG_2] = {"options", 4},
         [ARG_3] = {"ru", 4},
     }},
    {"waitid",
     284,
     NORMAL,
     {
         [ARG_0] = {"which", 4},
         [ARG_1] = {"upid", 4},
         [ARG_2] = {"infop", 4},
         [ARG_3] = {"options", 4},
         [ARG_4] = {"ru", 4},
     }},
    {"waitpid",
     7,
     NORMAL,
     {
         [ARG_0] = {"pid", 4},
         [ARG_1] = {"stat_addr", 4},
         [ARG_2] = {"options", 4},
     }},
    {"write",
     4,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"buf", 4},
         [ARG_2] = {"count", 4},
     }},
    {"writev",
     146,
     NORMAL,
     {
         [ARG_0] = {"fd", 4},
         [ARG_1] = {"vec", 4},
         [ARG_2] = {"vlen", 4},
     }},
};

const size_t i386_syscall_list_size =
    sizeof(i386_syscall_list) / sizeof(i386_syscall_list [0]);
